//go:generate go run github.com/oapi-codegen/oapi-codegen/v2/cmd/oapi-codegen --config=oapi-codegen.yml openapi.yml

package main

import (
	"code.dlmw.ch/dlmw/qv/internal/models"
	"database/sql"
	"fmt"
	"github.com/go-playground/form/v4"
	_ "github.com/mattn/go-sqlite3"
	"log/slog"
	"os"
)

type application struct {
	logger      *slog.Logger
	elections   models.ElectionModelInterface
	formDecoder *form.Decoder
}

func main() {
	logger := slog.New(slog.NewTextHandler(os.Stdout, nil))

	db, err := openDb()
	if err != nil {
		logger.Error(err.Error())
		os.Exit(1)
	}
	defer db.Close()

	formDecoder := form.NewDecoder()

	app := application{
		logger:      logger,
		elections:   &models.ElectionModel{DB: db},
		formDecoder: formDecoder,
	}

	fmt.Println(app)
}

func openDb() (*sql.DB, error) {
	db, err := sql.Open("sqlite3", "./qv.sqlite")
	if err == nil {
		err = db.Ping()
	}
	return db, err
}
